@@ -1,47 +1,14 @@
 import tensorflow as tf
-from scrinet.fits import nn
+import tensorflow_probability as tfp
+
 import numpy as np
 import arviz as az
 
-
-def load_amp_model(path_to_amp_model: str = 'amp/'):
-    """
-    helper to load Fitted scrinet Neural Network for amplitude basis
-    :param path_to_amp_model: Location of amp model to be used
-    :return:
-    """
-    model = nn.RegressionANN()
-    model.load_model(path_to_amp_model + "best.h5")
-    model.load_X_scalers(path_to_amp_model + "X_scalers.npy")
-    model.load_Y_scalers(path_to_amp_model + "Y_scalers.npy")
-    model.scaleX = True
-    model.scaleY = True
-
-    basis = np.load(path_to_amp_model + "amp_basis.npy")
-
-    return model, basis
+tfd = tfp.distributions
+tfb = tfp.bijectors
 
 
-def load_phase_model(path_to_phase_model: str = 'phase/'):
-    """
-    helper to load Fitted scrinet Neural Network for phase basis
-
-    :param path_to_phase_model: Location of phase model to be used
-    :return:
-    """
-    model = nn.RegressionANN()
-    model.load_model(path_to_phase_model + "best.h5")
-    model.load_X_scalers(path_to_phase_model + "X_scalers.npy")
-    model.load_Y_scalers(path_to_phase_model + "Y_scalers.npy")
-    model.scaleX = True
-    model.scaleY = True
-
-    basis = np.load(path_to_phase_model + "phase_basis.npy")
-
-    return model, basis
-
-
-@tf.function(experimental_compile=True, experimental_relax_shapes=True)
+@tf.function(experimental_compile=True, autograph=True, experimental_relax_shapes=True)
 def predict_hack(model, _input):
     """
     Function to re-create model.predict(input) but allows the graph to be built correctly
@@ -54,14 +21,14 @@ def predict_hack(model, _input):
     x = _input
     x = x_scale_hack(model, x)
     pred = tf.convert_to_tensor(x)
-    pred = tf.cast(pred, tf.float64)
-    # pred = x * tf.ones([len(x)], dtype=tf.float64)
-    # this should be an argument for ndim of problem
+    # the three should be an argument for ndim of problem
     pred = tf.reshape(pred, shape=(-1, 3))
-    for layer in model.model.layers:
+    net_layers = model.model.layers
+    output_shape = net_layers[-1].output_shape[-1]
+    for layer in net_layers:
         pred = layer(pred)
     pred = tf.reshape(
-        pred, shape=(-1, model.model.get_output_shape_at(-1)[1],))
+        pred, shape=(-1, output_shape,))
     pred = y_inv_scale_hack(model, pred)
     return pred
 
@@ -80,8 +47,8 @@ def x_scale_hack(model, _input):
                          for i in range(x.shape[0])])
     stds = tf.constant([model.X_scalers[i].scale_[0]
                         for i in range(x.shape[0])])
-    means = tf.cast(means, tf.float64)
-    stds = tf.cast(stds, tf.float64)
+    means = tf.cast(means, tf.float32)
+    stds = tf.cast(stds, tf.float32)
 
     x_scaled = (tf.reshape(x, shape=(-1, x.shape[0],)) - means) / stds
     x_scaled = tf.cast(x_scaled, tf.float32)
@@ -137,7 +104,7 @@ def y_inv_scale_hack(model, _input):
     return y
 
 
-@tf.function(experimental_compile=True, experimental_relax_shapes=True)
+# @tf.function(experimental_compile=True, experimental_relax_shapes=True)
 def generate_surrogate(x,
                        amp_model,
                        amp_basis,
@@ -156,15 +123,12 @@ def generate_surrogate(x,
 
     x = tf.transpose(
         tf.stack([tf.math.log(x[:, 0]), x[:, 1], x[:, 2]], axis=0))
-    x = tf.cast(x, tf.float64)
+    x = tf.cast(x, tf.float32)
     x = tf.reshape(x, shape=(-1, x.shape[0]))
-    x = tf.convert_to_tensor(x, dtype=tf.float64)
+    x = tf.convert_to_tensor(x, dtype=tf.float32)
 
     amp_alpha = predict_hack(amp_model, x)
 
-    amp_alpha = tf.cast(amp_alpha, tf.float64)
-    amp_basis = tf.cast(amp_basis, tf.float64)
-
     amp = tf.tensordot(amp_alpha,
                        amp_basis,
                        axes=1)
@@ -172,11 +136,6 @@ def generate_surrogate(x,
     phase_alpha = predict_hack(phase_model,
                                x)
 
-    phase_alpha = tf.cast(phase_alpha,
-                          tf.float32)
-    phase_basis = tf.cast(phase_basis,
-                          tf.float32)
-
     phase = tf.tensordot(phase_alpha,
                          phase_basis,
                          axes=1)
@@ -186,8 +145,8 @@ def generate_surrogate(x,
 
     h = amp * tf.math.exp(-1.j * phase)
     phase = tf.cast(phase, tf.float32)
-    phase = phase[0]
-    phase = phase - phase[0]
+    #phase = phase[0]
+    #phase = phase - phase[0]
 
     return tf.math.real(h), tf.math.imag(h), amp, phase
 
